
#Functions used by the new CI/CD workflow
REPO_CREDS="ubuntu@srvi-repo.int.centreon.com"

copy_internal_source_to_testing () {
  SRCDIR="/srv/sources/internal/$2/$3"
  DESTDIR="/srv/sources/$1/testing/$2/"
  ssh -o StrictHostKeyChecking=no "$REPO_CREDS" cp -r "$SRCDIR" "$DESTDIR"
}

upload_artifact_for_download () {
  SRCHASH=`ssh $REPO_CREDS "md5sum $6 | cut -d ' ' -f 1"`
  SRCSIZE=`ssh $REPO_CREDS "stat -c '%s' $6"`
  ssh $REPO_CREDS aws s3 cp --acl public-read "$6" "$7"
  curl "https://download.centreon.com/api/?token=$8&product=$1&release=$2&version=$3&extension=$4&md5=$SRCHASH&size=$SRCSIZE&ddos=$5&dryrun=0"
}

upload_tarball_for_download () {
  SERIE=`echo $2 | cut -d . -f 1-2`
  upload_artifact_for_download "$1" "$SERIE" "$2" tar.gz 0 "$3" "$4" "$5"
}

#Functions used by the new CI/CD workflow
clean_directory () {
  CMD='ls -drc '"$1/*"' | head -n -6 | xargs rm -rf'
  ssh -o StrictHostKeyChecking=no "$REPO_CREDS" "$CMD"
}

get_internal_source () {
  rm -f `basename $1`
  wget -q "http://srvi-repo.int.centreon.com/sources/internal/$1"
}

put_internal_source () {
  DIR="/srv/sources/internal/$1"
  NEWDIR="$2"
  ssh -o StrictHostKeyChecking=no "$REPO_CREDS" mkdir -p "$DIR/$NEWDIR"
  shift
  shift
  scp -r "$@" "$REPO_CREDS:$DIR/$NEWDIR"
  clean_directory "$DIR"
}

put_rpms () {

  # "REPO" "$MAJOR" "DISTRIB" "REPOTYPE" "ARCH" "PROJECT" "FOLDER" 'RPMS'

  # Checking if we push standard rpms or business modules for specific versions
  if [ "$1" = "standard" ] ; then
    PROJECT_PATH=standard
  elif [ "$1" = "business" ] && [ "$2" = "22.04" -o  "$2" = "21.10" -o "$2" = "21.04"] ; then
    PROJECT_PATH=centreon-business/1a97ff9985262bf3daf7a0919f9c59a6
  elif [ "$1" = "lts" ] ; then
    PROJECT_PATH=centreon-lts/1c0143e9c46ef424bc0c1ae9ba77203c17abf1cda7e
  elif [ "$1" = "bam" ] && [ "$2" = "20.04" -o "$2" = "20.10"] ; then
    PROJECT_PATH=centreon-bam/d4e1d7d3e888f596674453d1f20ff6d3
  elif [ "$1" = "map" ] && [ "$2" = "20.04" -o "$2" = "20.10"] ; then
    PROJECT_PATH=centreon-map/bfcfef6922ae08bd2b641324188d8a5f
  elif [ "$1" = "mbi" ] && [ "$2" = "20.04" -o "$2" = "20.10"] ; then
    PROJECT_PATH=centreon-mbi/5e0524c1c4773a938c44139ea9d8b4d7
  elif [ "$1" = "plugin-packs" ] ; then
    PROJECT_PATH=plugin-packs/2e83f5ff110c44a9cab8f8c7ebbe3c4f
  elif [ "$1" = "centreon-beta" ] ; then
    PROJECT_PATH=centreon-beta/09a7da422206046393db5d3d18ff44922023935f507f56aa5d05e6cf2c618844
  elif [ "$1" = "centreon-internal" ] ; then
    PROJECT_PATH=centreon-internal/6a9512566e3ba9b298064e3559cafbfc6f07cfbffe94f21f29e3455ade33b3b0
  fi

  #Local variables for the parameters that are used to create the targer path
  MAJOR=$2
  DISTRIB=$3
  REPOTYPE=$4
  ARCH=$5
  PROJECT=$6
  FOLDER=$7
  #Local variable for rpm put
  TARGET="/srv/centreon-yum/yum.centreon.com/$PROJECT_PATH/$MAJOR/$DISTRIB/$REPOTYPE/$ARCH/$PROJECT/$FOLDER"
  #Local variable for cleaning project directory to keep only six rpms projects
  PROJECT_LOCATION="/srv/centreon-yum/yum.centreon.com/$PROJECT_PATH/$MAJOR/$DISTRIB/$REPOTYPE/$ARCH/$PROJECT"
  METADATAS="/srv/centreon-yum/yum.centreon.com/$PROJECT_PATH/$MAJOR/$DISTRIB/$REPOTYPE/$ARCH"
  ssh -o StrictHostKeyChecking=no "cesync@yum.int.centreon.com" mkdir -p "$TARGET"
  shift 7
  scp -o StrictHostKeyChecking=no "$@" "cesync@yum.int.centreon.com:$TARGET"
  ssh -o StrictHostKeyChecking=no "cesync@yum.int.centreon.com" createrepo --update "$METADATAS"
  ssh -o StrictHostKeyChecking=no "ubuntu@srvi-repo.int.centreon.com" aws cloudfront create-invalidation --distribution-id E34EBWWERP6QET --paths "/$PROJECT_PATH/$MAJOR/$DISTRIB/$REPOTYPE/$ARCH/*"
}

promote_rpms_from_testing_to_stable () {

  # Checking if we push standard rpms or business modules
  if [ "$1" = "standard" ] ; then
    PROJECT_PATH=standard
  elif [ "$1" = "business" ] && [ "$2" = "22.04" -o "$2" = "21.10" -o "$2" = "21.04"] ; then
    PROJECT_PATH=centreon-business/1a97ff9985262bf3daf7a0919f9c59a6
  elif [ "$1" = "lts" ] ; then
    PROJECT_PATH=centreon-lts/1c0143e9c46ef424bc0c1ae9ba77203c17abf1cda7e
  elif [ "$1" = "bam" ] && [ "$2" = "20.04" -o "$2" = "20.10"] ; then
    PROJECT_PATH=centreon-bam/d4e1d7d3e888f596674453d1f20ff6d3
  elif [ "$1" = "map" ] && [ "$2" = "20.04" -o "$2" = "20.10"] ; then
    PROJECT_PATH=centreon-map/bfcfef6922ae08bd2b641324188d8a5f
  elif [ "$1" = "mbi" ] && [ "$2" = "20.04" -o "$2" = "20.10"] ; then
    PROJECT_PATH=centreon-mbi/5e0524c1c4773a938c44139ea9d8b4d7
  elif [ "$1" = "plugin-packs" ] ; then
    PROJECT_PATH=plugin-packs/2e83f5ff110c44a9cab8f8c7ebbe3c4f
  elif [ "$1" = "centreon-beta" ] ; then
    PROJECT_PATH=centreon-beta/09a7da422206046393db5d3d18ff44922023935f507f56aa5d05e6cf2c618844
  elif [ "$1" = "centreon-internal" ] ; then
    PROJECT_PATH=centreon-internal/6a9512566e3ba9b298064e3559cafbfc6f07cfbffe94f21f29e3455ade33b3b0
  fi
  
  #Local variables for the parameters that are used to create the targer path
  MAJOR=$2
  DISTRIB=$3
  ARCH=$4
  PROJECT=$5
  FOLDER=$6

  #Local variable for testing rpm dir
  SOURCE="/srv/centreon-yum/yum.centreon.com/$PROJECT_PATH/$MAJOR/$DISTRIB/testing/$ARCH/$PROJECT/$FOLDER"
  #Local variable for stable rpm dir
  TARGET="/srv/centreon-yum/yum.centreon.com/$PROJECT_PATH/$MAJOR/$DISTRIB/stable/$ARCH/RPMS"
  #Local variable for metadatas updates
  METADATAS="/srv/centreon-yum/yum.centreon.com/$PROJECT_PATH/$MAJOR/$DISTRIB/stable/$ARCH"

  #Create directory and copy rpm from testing repo to the stable repo
  ssh -o StrictHostKeyChecking=no "cesync@yum.int.centreon.com" mkdir -p "$TARGET"
  ssh -o StrictHostKeyChecking=no "cesync@yum.int.centreon.com" cp $SOURCE/*.rpm $TARGET/

  #Update metadatas and invalidate cache on cloudfront
  ssh -o StrictHostKeyChecking=no "cesync@yum.int.centreon.com" createrepo --update "$METADATAS"
  ssh -o StrictHostKeyChecking=no "ubuntu@srvi-repo.int.centreon.com" aws cloudfront create-invalidation --distribution-id E34EBWWERP6QET --paths "/$PROJECT_PATH/$MAJOR/$DISTRIB/stable/$ARCH/*"
}
